package com.lemoulinstudio.jnag.utils.rds.client;

import com.sun.sgs.client.ClientChannel;
import java.io.IOException;
import java.nio.ByteBuffer;
import com.lemoulinstudio.jnag.common.MessageListener;

/**
 * An implementation of the {@link MessageListener} which transmits messages
 * to a specified Red Dwarf client channel.
 *
 * @author Vincent Cantin
 */
public class MessageSenderToClientChannel implements MessageListener {

  private ClientChannel clientChannel;
  
  /**
   * Creates an instance of a {@link MessageListener} that forward message
   * to the specified Red Dwarf client channel.
   *
   * @param clientChannel The Red Dwarf client channel where
   * all the messages will be forwarded.
   */
  public MessageSenderToClientChannel(ClientChannel clientChannel) {
    this.clientChannel = clientChannel;
  }

  /**
   * Returns the Red Dwarf client channel that has been specified in the contructor.
   *
   * @return The Red Dwarf client channel.
   */
  public ClientChannel getClientChannel() {
    return clientChannel;
  }
  
  /**
   * {@inheritDoc}
   */
  @Override
  public void notifyMessage(ByteBuffer binaryMessage) {
    try {
      clientChannel.send(binaryMessage);
    } catch (IOException ex) {
      ex.printStackTrace();
    }
  }

}
