package com.lemoulinstudio.jnag.utils.rds.client;

import com.sun.sgs.client.ServerSession;
import java.io.IOException;
import java.nio.ByteBuffer;
import com.lemoulinstudio.jnag.common.MessageListener;

/**
 * An implementation of the {@link MessageListener} which transmits messages
 * to a specified Red Dwarf server session.
 *
 * @author Vincent Cantin
 */
public class MessageSenderToServerSession implements MessageListener {

  private ServerSession serverSession;

  /**
   * Creates an instance of a {@link MessageListener} that forward message
   * to the specified Red Dwarf server session.
   *
   * @param serverSession The Red Dwarf server session where
   * all the messages will be forwarded.
   */
  public MessageSenderToServerSession(ServerSession serverSession) {
    this.serverSession = serverSession;
  }

  /**
   * Returns the Red Dwarf server session that has been specified in the contructor.
   *
   * @return The Red Dwarf server session.
   */
  public ServerSession getServerSession() {
    return serverSession;
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void notifyMessage(ByteBuffer binaryMessage) {
    try {
      serverSession.send(binaryMessage);
    } catch (IOException e) {
      e.printStackTrace();
    }
  }

}
